@@ -40,12 +40,6 @@ manager = None
 DB_CLEANUP_INTERVAL = timedelta(days=7)
 
 
-@sqlalchemy.event.listens_for(Session, 'before_commit')
-def before_commit(session):
-    if not manager.has_lock and session.dirty:
-        log.debug('BUG?: Database writes should not be tried when there is no database lock.')
-
-
 @sqlalchemy.event.listens_for(sqlalchemy.engine.Engine, 'connect')
 def set_sqlite_pragma(dbapi_connection, connection_record):
     cursor = dbapi_connection.cursor()
